%define pypi_name eventlet

Name:           python-%{pypi_name}
Version:        0.35.0
Release:        %mkrel 1
Summary:        Highly concurrent networking library
License:        MIT
Group:          Development/Python
URL:            https://eventlet.net/
Source0:        %{pypi_source}
# patch is from gh#rthalley/dnspython#519, discussion in gh#eventlet/eventlet#638
Patch1:         newdnspython.patch
BuildArch:      noarch

%description
Eventlet is a networking library written in Python. It achieves high
scalability by using non-blocking io while at the same time retaining
high programmer usability by using coroutines to make the non-blocking
io operations appear blocking at the source code level.

%package -n     python3-%{pypi_name}
Summary:        %{summary}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
BuildRequires:  pkgconfig(python3)

Recommends:     python3dist(pyzmq)

%description -n python3-%{pypi_name}
Eventlet is a networking library written in Python 3. It achieves high
scalability by using non-blocking io while at the same time retaining
high programmer usability by using coroutines to make the non-blocking
io operations appear blocking at the source code level.
This is the Python 3 build of %{pypi_name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Development/Python
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinxcontrib-apidoc)
BuildRequires:  python3dist(tox)
BuildRequires:  python3dist(monotonic)
BuildRequires:  python3dist(dnspython)
BuildRequires:  python3dist(pyzmq)
BuildRequires:  python3dist(hatch-vcs)

%description    doc
Documentation for the python-eventlet package.

%prep
%setup -q -n %{pypi_name}-%{version}
%autopatch -p1

# relax sphinx requirement
sed -i "s/>=2.0.0,!=2.1.0//" doc/requirements.txt

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel
PYTHONPATH=${PWD} sphinx-build -b html doc/source doc/build/html

%install
%pyproject_install
%pyproject_save_files eventlet

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc AUTHORS LICENSE NEWS README.rst


%files doc
%doc examples tests
%doc doc/build/html


%changelog
* Mon Jan 22 2024 papoteur <papoteur> 0.35.0-1.mga10
+ Revision: 2033654
- new version 0.35.0
- use pyproject generate_buildrequires
- include really the documentation

* Wed Sep 07 2022 neoclust <neoclust> 0.33.1-1.mga9
+ Revision: 1884704
- New version  0.33.1

* Sun Apr 03 2022 umeabot <umeabot> 0.33.0-2.mga9
+ Revision: 1841228
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 mrambo3501 <mrambo3501> 0.33.0-1.mga9
+ Revision: 1788176
- version 0.33.0
- rediff Patch1
- delete Patch2 applied upstream
- rebuild for python-3.10

* Sat Aug 28 2021 wally <wally> 0.31.1-1.mga9
+ Revision: 1743223
- new version 0.31.1

* Mon Jun 07 2021 daviddavid <daviddavid> 0.31.0-1.mga9
+ Revision: 1730018
- new version: 0.31.0, fixes CVE-2021-21419 (mga#29009)

* Fri Apr 23 2021 daviddavid <daviddavid> 0.30.2-2.mga9
+ Revision: 1718185
- rebuild for python 3.9

* Mon Mar 08 2021 daviddavid <daviddavid> 0.30.2-1.mga9
+ Revision: 1700692
- new version: 0.30.2

* Mon Mar 01 2021 daviddavid <daviddavid> 0.30.1-1.mga9
+ Revision: 1695071
- new version: 0.30.1

* Sat Nov 28 2020 guillomovitch <guillomovitch> 0.29.1-1.mga8
+ Revision: 1649913
- new version 0.29.1

* Fri Oct 23 2020 daviddavid <daviddavid> 0.26.0-1.mga8
+ Revision: 1638951
- new version: 0.26.0

* Fri May 01 2020 daviddavid <daviddavid> 0.25.2-1.mga8
+ Revision: 1577406
- new version: 0.25.2

* Sun Feb 16 2020 umeabot <umeabot> 0.25.1-2.mga8
+ Revision: 1534273
- Mageia 8 Mass Rebuild

* Wed Oct 02 2019 daviddavid <daviddavid> 0.25.1-1.mga8
+ Revision: 1448751
- new version: 0.25.1

* Mon Sep 16 2019 daviddavid <daviddavid> 0.25.0-3.mga8
+ Revision: 1441816
- rebuild for python3.8
- drop python2 support

* Sun Aug 18 2019 wally <wally> 0.25.0-2.mga8
+ Revision: 1429745
- update sphinx BRs

* Sun Jul 07 2019 daviddavid <daviddavid> 0.25.0-1.mga8
+ Revision: 1419304
- new version: 0.25.0

* Tue Jan 08 2019 shlomif <shlomif> 0.24.1-1.mga7
+ Revision: 1352675
- Rebuild for python3 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.23.0-2.mga7
+ Revision: 1288825
- Mageia 7 Mass Rebuild

* Sat Jun 16 2018 daviddavid <daviddavid> 0.23.0-1.mga7
+ Revision: 1237176
- new version: 0.23.0

* Thu Apr 05 2018 kekepower <kekepower> 0.19.0-1.mga7
+ Revision: 1215394
- Update to version 0.19.0
- Renamed python-eventlet to python2-eventlet

* Sat Aug 05 2017 pterjan <pterjan> 0.17.4-2.mga7
+ Revision: 1135416
- Rebuild for python 3.6

* Thu Dec 17 2015 daviddavid <daviddavid> 0.17.4-1.mga6
+ Revision: 911235
- new version: 0.17.4
- add python 3 package
- use new python macros

* Wed Oct 15 2014 umeabot <umeabot> 0.13.0-7.mga5
+ Revision: 741748
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.13.0-6.mga5
+ Revision: 728435
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.13.0-3.mga4
+ Revision: 543315
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.13.0-2.mga4
+ Revision: 498558
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 18 2013 joequant <joequant> 0.13.0-1.mga4
+ Revision: 467412
- upgrade to 0.13.0

* Sun Jan 13 2013 umeabot <umeabot> 0.9.16-2.mga3
+ Revision: 378809
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 03 2012 neoclust <neoclust> 0.9.16-1.mga3
+ Revision: 313205
- imported package python-eventlet


* Thu Jan 12 2012 Lev Givon <lev@mandriva.org> 0.9.16-1mdv2012.0
+ Revision: 760422
- Update to 0.9.16.
  Remove greenpipe patch (no longer needed).
  Suggest installation of python-pyzmq.

* Thu Jun 09 2011 Antoine Ginies <aginies@mandriva.com> 0.9.14-1
+ Revision: 683432
- fix group
- import python-eventlet


* Wed Jun 8 2011 Antoine Ginies <aginies@mandriva.com> 0.9.14
- first release for Mandriva
